"""
Type annotations for securitylake service client.

[Open documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/client/)

Usage::

    ```python
    from aiobotocore.session import get_session
    from types_aiobotocore_securitylake.client import SecurityLakeClient

    session = get_session()
    async with session.create_client("securitylake") as client:
        client: SecurityLakeClient
    ```
"""
import sys
from typing import Any, Dict, Mapping, Sequence, Type, overload

from aiobotocore.client import AioBaseClient
from botocore.client import ClientMeta

from .literals import (
    AccessTypeType,
    DimensionType,
    HttpsMethodType,
    OcsfEventClassType,
    RegionType,
    SubscriptionProtocolTypeType,
)
from .paginator import (
    GetDatalakeStatusPaginator,
    ListDatalakeExceptionsPaginator,
    ListLogSourcesPaginator,
    ListSubscribersPaginator,
)
from .type_defs import (
    AutoEnableNewRegionConfigurationTypeDef,
    CreateAwsLogSourceResponseTypeDef,
    CreateCustomLogSourceResponseTypeDef,
    CreateSubscriberResponseTypeDef,
    CreateSubscriptionNotificationConfigurationResponseTypeDef,
    DeleteAwsLogSourceResponseTypeDef,
    DeleteCustomLogSourceResponseTypeDef,
    DeleteDatalakeExceptionsSubscriptionResponseTypeDef,
    GetDatalakeAutoEnableResponseTypeDef,
    GetDatalakeExceptionsExpiryResponseTypeDef,
    GetDatalakeExceptionsSubscriptionResponseTypeDef,
    GetDatalakeResponseTypeDef,
    GetDatalakeStatusResponseTypeDef,
    GetSubscriberResponseTypeDef,
    LakeConfigurationRequestTypeDef,
    ListDatalakeExceptionsResponseTypeDef,
    ListLogSourcesResponseTypeDef,
    ListSubscribersResponseTypeDef,
    SourceTypeTypeDef,
    UpdateSubscriberResponseTypeDef,
    UpdateSubscriptionNotificationConfigurationResponseTypeDef,
)

if sys.version_info >= (3, 9):
    from typing import Literal
else:
    from typing_extensions import Literal

__all__ = ("SecurityLakeClient",)

class BotocoreClientError(BaseException):
    MSG_TEMPLATE: str

    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
        self.response: Dict[str, Any]
        self.operation_name: str

class Exceptions:
    AccessDeniedException: Type[BotocoreClientError]
    AccountNotFoundException: Type[BotocoreClientError]
    BucketNotFoundException: Type[BotocoreClientError]
    ClientError: Type[BotocoreClientError]
    ConcurrentModificationException: Type[BotocoreClientError]
    ConflictException: Type[BotocoreClientError]
    ConflictSourceNamesException: Type[BotocoreClientError]
    ConflictSubscriptionException: Type[BotocoreClientError]
    EventBridgeException: Type[BotocoreClientError]
    InternalServerException: Type[BotocoreClientError]
    InvalidInputException: Type[BotocoreClientError]
    ResourceNotFoundException: Type[BotocoreClientError]
    S3Exception: Type[BotocoreClientError]
    ServiceQuotaExceededException: Type[BotocoreClientError]
    ThrottlingException: Type[BotocoreClientError]
    ValidationException: Type[BotocoreClientError]

class SecurityLakeClient(AioBaseClient):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Client)
    [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/client/)
    """

    meta: ClientMeta

    @property
    def exceptions(self) -> Exceptions:
        """
        SecurityLakeClient exceptions.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Client.exceptions)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/client/#exceptions)
        """
    def can_paginate(self, operation_name: str) -> bool:
        """
        Check if an operation can be paginated.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Client.can_paginate)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/client/#can_paginate)
        """
    async def close(self) -> None:
        """
        Closes underlying endpoint connections.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Client.close)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/client/#close)
        """
    async def create_aws_log_source(
        self,
        *,
        inputOrder: Sequence[DimensionType],
        enableAllDimensions: Mapping[str, Mapping[str, Sequence[str]]] = ...,
        enableSingleDimension: Sequence[str] = ...,
        enableTwoDimensions: Mapping[str, Sequence[str]] = ...
    ) -> CreateAwsLogSourceResponseTypeDef:
        """
        Adds a natively supported Amazon Web Service as an Amazon Security Lake source.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Client.create_aws_log_source)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/client/#create_aws_log_source)
        """
    async def create_custom_log_source(
        self,
        *,
        customSourceName: str,
        eventClass: OcsfEventClassType,
        glueInvocationRoleArn: str,
        logProviderAccountId: str
    ) -> CreateCustomLogSourceResponseTypeDef:
        """
        Adds a third-party custom source in Amazon Security Lake, from the Amazon Web
        Services Region where you want to create a custom source.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Client.create_custom_log_source)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/client/#create_custom_log_source)
        """
    async def create_datalake(
        self,
        *,
        configurations: Mapping[RegionType, LakeConfigurationRequestTypeDef] = ...,
        enableAll: bool = ...,
        metaStoreManagerRoleArn: str = ...,
        regions: Sequence[RegionType] = ...
    ) -> Dict[str, Any]:
        """
        Initializes an Amazon Security Lake instance with the provided (or default)
        configuration.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Client.create_datalake)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/client/#create_datalake)
        """
    async def create_datalake_auto_enable(
        self, *, configurationForNewAccounts: Sequence[AutoEnableNewRegionConfigurationTypeDef]
    ) -> Dict[str, Any]:
        """
        Automatically enables Amazon Security Lake for new member accounts in your
        organization.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Client.create_datalake_auto_enable)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/client/#create_datalake_auto_enable)
        """
    async def create_datalake_delegated_admin(self, *, account: str) -> Dict[str, Any]:
        """
        Designates the Amazon Security Lake delegated administrator account for the
        organization.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Client.create_datalake_delegated_admin)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/client/#create_datalake_delegated_admin)
        """
    async def create_datalake_exceptions_subscription(
        self, *, notificationEndpoint: str, subscriptionProtocol: SubscriptionProtocolTypeType
    ) -> Dict[str, Any]:
        """
        Creates the specified notification subscription in Amazon Security Lake for the
        organization you specify.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Client.create_datalake_exceptions_subscription)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/client/#create_datalake_exceptions_subscription)
        """
    async def create_subscriber(
        self,
        *,
        accountId: str,
        externalId: str,
        sourceTypes: Sequence[SourceTypeTypeDef],
        subscriberName: str,
        accessTypes: Sequence[AccessTypeType] = ...,
        subscriberDescription: str = ...
    ) -> CreateSubscriberResponseTypeDef:
        """
        Creates a subscription permission for accounts that are already enabled in
        Amazon Security Lake.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Client.create_subscriber)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/client/#create_subscriber)
        """
    async def create_subscription_notification_configuration(
        self,
        *,
        subscriptionId: str,
        createSqs: bool = ...,
        httpsApiKeyName: str = ...,
        httpsApiKeyValue: str = ...,
        httpsMethod: HttpsMethodType = ...,
        roleArn: str = ...,
        subscriptionEndpoint: str = ...
    ) -> CreateSubscriptionNotificationConfigurationResponseTypeDef:
        """
        Notifies the subscriber when new data is written to the data lake for the
        sources that the subscriber consumes in Security Lake.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Client.create_subscription_notification_configuration)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/client/#create_subscription_notification_configuration)
        """
    async def delete_aws_log_source(
        self,
        *,
        inputOrder: Sequence[DimensionType],
        disableAllDimensions: Mapping[str, Mapping[str, Sequence[str]]] = ...,
        disableSingleDimension: Sequence[str] = ...,
        disableTwoDimensions: Mapping[str, Sequence[str]] = ...
    ) -> DeleteAwsLogSourceResponseTypeDef:
        """
        Removes a natively supported Amazon Web Service as an Amazon Security Lake
        source.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Client.delete_aws_log_source)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/client/#delete_aws_log_source)
        """
    async def delete_custom_log_source(
        self, *, customSourceName: str
    ) -> DeleteCustomLogSourceResponseTypeDef:
        """
        Removes a custom log source from Amazon Security Lake.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Client.delete_custom_log_source)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/client/#delete_custom_log_source)
        """
    async def delete_datalake(self) -> Dict[str, Any]:
        """
        When you delete Amazon Security Lake from your account, Security Lake is
        disabled in all Amazon Web Services Regions.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Client.delete_datalake)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/client/#delete_datalake)
        """
    async def delete_datalake_auto_enable(
        self,
        *,
        removeFromConfigurationForNewAccounts: Sequence[AutoEnableNewRegionConfigurationTypeDef]
    ) -> Dict[str, Any]:
        """
        Automatically deletes Amazon Security Lake to stop collecting security data.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Client.delete_datalake_auto_enable)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/client/#delete_datalake_auto_enable)
        """
    async def delete_datalake_delegated_admin(self, *, account: str) -> Dict[str, Any]:
        """
        Deletes the Amazon Security Lake delegated administrator account for the
        organization.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Client.delete_datalake_delegated_admin)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/client/#delete_datalake_delegated_admin)
        """
    async def delete_datalake_exceptions_subscription(
        self,
    ) -> DeleteDatalakeExceptionsSubscriptionResponseTypeDef:
        """
        Deletes the specified notification subscription in Amazon Security Lake for the
        organization you specify.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Client.delete_datalake_exceptions_subscription)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/client/#delete_datalake_exceptions_subscription)
        """
    async def delete_subscriber(self, *, id: str) -> Dict[str, Any]:
        """
        Deletes the subscription permission for accounts that are already enabled in
        Amazon Security Lake.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Client.delete_subscriber)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/client/#delete_subscriber)
        """
    async def delete_subscription_notification_configuration(
        self, *, subscriptionId: str
    ) -> Dict[str, Any]:
        """
        Deletes the specified notification subscription in Amazon Security Lake for the
        organization you specify.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Client.delete_subscription_notification_configuration)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/client/#delete_subscription_notification_configuration)
        """
    async def generate_presigned_url(
        self,
        ClientMethod: str,
        Params: Mapping[str, Any] = ...,
        ExpiresIn: int = 3600,
        HttpMethod: str = ...,
    ) -> str:
        """
        Generate a presigned url given a client, its method, and arguments.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Client.generate_presigned_url)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/client/#generate_presigned_url)
        """
    async def get_datalake(self) -> GetDatalakeResponseTypeDef:
        """
        Retrieves the Amazon Security Lake configuration object for the specified Amazon
        Web Services account ID.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Client.get_datalake)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/client/#get_datalake)
        """
    async def get_datalake_auto_enable(self) -> GetDatalakeAutoEnableResponseTypeDef:
        """
        Retrieves the configuration that will be automatically set up for accounts added
        to the organization after the organization has onboarded to Amazon Security
        Lake.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Client.get_datalake_auto_enable)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/client/#get_datalake_auto_enable)
        """
    async def get_datalake_exceptions_expiry(self) -> GetDatalakeExceptionsExpiryResponseTypeDef:
        """
        Retrieves the expiration period and time-to-live (TTL) for which the exception
        message will remain.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Client.get_datalake_exceptions_expiry)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/client/#get_datalake_exceptions_expiry)
        """
    async def get_datalake_exceptions_subscription(
        self,
    ) -> GetDatalakeExceptionsSubscriptionResponseTypeDef:
        """
        Retrieves the details of exception notifications for the account in Amazon
        Security Lake.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Client.get_datalake_exceptions_subscription)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/client/#get_datalake_exceptions_subscription)
        """
    async def get_datalake_status(
        self, *, accountSet: Sequence[str] = ..., maxAccountResults: int = ..., nextToken: str = ...
    ) -> GetDatalakeStatusResponseTypeDef:
        """
        Retrieves a snapshot of the current Region, including whether Amazon Security
        Lake is enabled for those accounts and which sources Security Lake is collecting
        data from.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Client.get_datalake_status)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/client/#get_datalake_status)
        """
    async def get_subscriber(self, *, id: str) -> GetSubscriberResponseTypeDef:
        """
        Retrieves the subscription information for the specified subscription ID.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Client.get_subscriber)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/client/#get_subscriber)
        """
    async def list_datalake_exceptions(
        self, *, maxFailures: int = ..., nextToken: str = ..., regionSet: Sequence[RegionType] = ...
    ) -> ListDatalakeExceptionsResponseTypeDef:
        """
        Lists the Amazon Security Lake exceptions that you can use to find the source of
        problems and fix them.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Client.list_datalake_exceptions)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/client/#list_datalake_exceptions)
        """
    async def list_log_sources(
        self,
        *,
        inputOrder: Sequence[DimensionType] = ...,
        listAllDimensions: Mapping[str, Mapping[str, Sequence[str]]] = ...,
        listSingleDimension: Sequence[str] = ...,
        listTwoDimensions: Mapping[str, Sequence[str]] = ...,
        maxResults: int = ...,
        nextToken: str = ...
    ) -> ListLogSourcesResponseTypeDef:
        """
        Retrieves the log sources in the current Amazon Web Services Region.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Client.list_log_sources)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/client/#list_log_sources)
        """
    async def list_subscribers(
        self, *, maxResults: int = ..., nextToken: str = ...
    ) -> ListSubscribersResponseTypeDef:
        """
        List all subscribers for the specific Amazon Security Lake account ID.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Client.list_subscribers)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/client/#list_subscribers)
        """
    async def update_datalake(
        self, *, configurations: Mapping[RegionType, LakeConfigurationRequestTypeDef]
    ) -> Dict[str, Any]:
        """
        Specifies where to store your security data and for how long.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Client.update_datalake)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/client/#update_datalake)
        """
    async def update_datalake_exceptions_expiry(
        self, *, exceptionMessageExpiry: int
    ) -> Dict[str, Any]:
        """
        Update the expiration period for the exception message to your preferred time,
        and control the time-to-live (TTL) for the exception message to remain.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Client.update_datalake_exceptions_expiry)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/client/#update_datalake_exceptions_expiry)
        """
    async def update_datalake_exceptions_subscription(
        self, *, notificationEndpoint: str, subscriptionProtocol: SubscriptionProtocolTypeType
    ) -> Dict[str, Any]:
        """
        Updates the specified notification subscription in Amazon Security Lake for the
        organization you specify.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Client.update_datalake_exceptions_subscription)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/client/#update_datalake_exceptions_subscription)
        """
    async def update_subscriber(
        self,
        *,
        id: str,
        sourceTypes: Sequence[SourceTypeTypeDef],
        externalId: str = ...,
        subscriberDescription: str = ...,
        subscriberName: str = ...
    ) -> UpdateSubscriberResponseTypeDef:
        """
        Updates an existing subscription for the given Amazon Security Lake account ID.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Client.update_subscriber)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/client/#update_subscriber)
        """
    async def update_subscription_notification_configuration(
        self,
        *,
        subscriptionId: str,
        createSqs: bool = ...,
        httpsApiKeyName: str = ...,
        httpsApiKeyValue: str = ...,
        httpsMethod: HttpsMethodType = ...,
        roleArn: str = ...,
        subscriptionEndpoint: str = ...
    ) -> UpdateSubscriptionNotificationConfigurationResponseTypeDef:
        """
        Creates a new subscription notification or adds the existing subscription
        notification setting for the specified subscription ID.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Client.update_subscription_notification_configuration)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/client/#update_subscription_notification_configuration)
        """
    @overload
    def get_paginator(
        self, operation_name: Literal["get_datalake_status"]
    ) -> GetDatalakeStatusPaginator:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Client.get_paginator)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/client/#get_paginator)
        """
    @overload
    def get_paginator(
        self, operation_name: Literal["list_datalake_exceptions"]
    ) -> ListDatalakeExceptionsPaginator:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Client.get_paginator)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/client/#get_paginator)
        """
    @overload
    def get_paginator(self, operation_name: Literal["list_log_sources"]) -> ListLogSourcesPaginator:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Client.get_paginator)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/client/#get_paginator)
        """
    @overload
    def get_paginator(
        self, operation_name: Literal["list_subscribers"]
    ) -> ListSubscribersPaginator:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Client.get_paginator)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/client/#get_paginator)
        """
    async def __aenter__(self) -> "SecurityLakeClient":
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Client)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/client/)
        """
    async def __aexit__(self, exc_type: Any, exc_val: Any, exc_tb: Any) -> Any:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Client)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/client/)
        """



"""
Main interface for securitylake service.

Usage::

    ```python
    from aiobotocore.session import get_session
    from types_aiobotocore_securitylake import (
        Client,
        GetDatalakeStatusPaginator,
        ListDatalakeExceptionsPaginator,
        ListLogSourcesPaginator,
        ListSubscribersPaginator,
        SecurityLakeClient,
    )

    session = get_session()
    async with session.create_client("securitylake") as client:
        client: SecurityLakeClient
        ...


    get_datalake_status_paginator: GetDatalakeStatusPaginator = client.get_paginator("get_datalake_status")
    list_datalake_exceptions_paginator: ListDatalakeExceptionsPaginator = client.get_paginator("list_datalake_exceptions")
    list_log_sources_paginator: ListLogSourcesPaginator = client.get_paginator("list_log_sources")
    list_subscribers_paginator: ListSubscribersPaginator = client.get_paginator("list_subscribers")
    ```
"""
from .client import SecurityLakeClient
from .paginator import (
    GetDatalakeStatusPaginator,
    ListDatalakeExceptionsPaginator,
    ListLogSourcesPaginator,
    ListSubscribersPaginator,
)

Client = SecurityLakeClient


__all__ = (
    "Client",
    "GetDatalakeStatusPaginator",
    "ListDatalakeExceptionsPaginator",
    "ListLogSourcesPaginator",
    "ListSubscribersPaginator",
    "SecurityLakeClient",
)



"""
Type annotations for securitylake service type definitions.

[Open documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/type_defs/)

Usage::

    ```python
    from types_aiobotocore_securitylake.type_defs import LogsStatusTypeDef

    data: LogsStatusTypeDef = {...}
    ```
"""
import sys
from datetime import datetime
from typing import Dict, List, Mapping, Sequence

from .literals import (
    AccessTypeType,
    AwsLogSourceTypeType,
    DimensionType,
    EndpointProtocolType,
    HttpsMethodType,
    OcsfEventClassType,
    RegionType,
    SourceStatusType,
    StorageClassType,
    SubscriptionProtocolTypeType,
    SubscriptionStatusType,
    settingsStatusType,
)

if sys.version_info >= (3, 9):
    from typing import TypedDict
else:
    from typing_extensions import TypedDict


__all__ = (
    "LogsStatusTypeDef",
    "AutoEnableNewRegionConfigurationTypeDef",
    "CreateAwsLogSourceRequestRequestTypeDef",
    "ResponseMetadataTypeDef",
    "CreateCustomLogSourceRequestRequestTypeDef",
    "CreateDatalakeDelegatedAdminRequestRequestTypeDef",
    "CreateDatalakeExceptionsSubscriptionRequestRequestTypeDef",
    "SourceTypeTypeDef",
    "CreateSubscriptionNotificationConfigurationRequestRequestTypeDef",
    "DeleteAwsLogSourceRequestRequestTypeDef",
    "DeleteCustomLogSourceRequestRequestTypeDef",
    "DeleteDatalakeDelegatedAdminRequestRequestTypeDef",
    "DeleteSubscriberRequestRequestTypeDef",
    "DeleteSubscriptionNotificationConfigurationRequestRequestTypeDef",
    "FailuresTypeDef",
    "ProtocolAndNotificationEndpointTypeDef",
    "PaginatorConfigTypeDef",
    "GetDatalakeStatusRequestRequestTypeDef",
    "GetSubscriberRequestRequestTypeDef",
    "RetentionSettingTypeDef",
    "ListDatalakeExceptionsRequestRequestTypeDef",
    "ListLogSourcesRequestRequestTypeDef",
    "ListSubscribersRequestRequestTypeDef",
    "UpdateDatalakeExceptionsExpiryRequestRequestTypeDef",
    "UpdateDatalakeExceptionsSubscriptionRequestRequestTypeDef",
    "UpdateSubscriptionNotificationConfigurationRequestRequestTypeDef",
    "AccountSourcesTypeDef",
    "CreateDatalakeAutoEnableRequestRequestTypeDef",
    "DeleteDatalakeAutoEnableRequestRequestTypeDef",
    "CreateAwsLogSourceResponseTypeDef",
    "CreateCustomLogSourceResponseTypeDef",
    "CreateSubscriberResponseTypeDef",
    "CreateSubscriptionNotificationConfigurationResponseTypeDef",
    "DeleteAwsLogSourceResponseTypeDef",
    "DeleteCustomLogSourceResponseTypeDef",
    "DeleteDatalakeExceptionsSubscriptionResponseTypeDef",
    "GetDatalakeAutoEnableResponseTypeDef",
    "GetDatalakeExceptionsExpiryResponseTypeDef",
    "ListLogSourcesResponseTypeDef",
    "UpdateSubscriptionNotificationConfigurationResponseTypeDef",
    "CreateSubscriberRequestRequestTypeDef",
    "SubscriberResourceTypeDef",
    "UpdateSubscriberRequestRequestTypeDef",
    "FailuresResponseTypeDef",
    "GetDatalakeExceptionsSubscriptionResponseTypeDef",
    "GetDatalakeStatusRequestGetDatalakeStatusPaginateTypeDef",
    "ListDatalakeExceptionsRequestListDatalakeExceptionsPaginateTypeDef",
    "ListLogSourcesRequestListLogSourcesPaginateTypeDef",
    "ListSubscribersRequestListSubscribersPaginateTypeDef",
    "LakeConfigurationRequestTypeDef",
    "LakeConfigurationResponseTypeDef",
    "GetDatalakeStatusResponseTypeDef",
    "GetSubscriberResponseTypeDef",
    "ListSubscribersResponseTypeDef",
    "UpdateSubscriberResponseTypeDef",
    "ListDatalakeExceptionsResponseTypeDef",
    "CreateDatalakeRequestRequestTypeDef",
    "UpdateDatalakeRequestRequestTypeDef",
    "GetDatalakeResponseTypeDef",
)

LogsStatusTypeDef = TypedDict(
    "LogsStatusTypeDef",
    {
        "healthStatus": SourceStatusType,
        "pathToLogs": str,
    },
)

AutoEnableNewRegionConfigurationTypeDef = TypedDict(
    "AutoEnableNewRegionConfigurationTypeDef",
    {
        "region": RegionType,
        "sources": Sequence[AwsLogSourceTypeType],
    },
)

_RequiredCreateAwsLogSourceRequestRequestTypeDef = TypedDict(
    "_RequiredCreateAwsLogSourceRequestRequestTypeDef",
    {
        "inputOrder": Sequence[DimensionType],
    },
)
_OptionalCreateAwsLogSourceRequestRequestTypeDef = TypedDict(
    "_OptionalCreateAwsLogSourceRequestRequestTypeDef",
    {
        "enableAllDimensions": Mapping[str, Mapping[str, Sequence[str]]],
        "enableSingleDimension": Sequence[str],
        "enableTwoDimensions": Mapping[str, Sequence[str]],
    },
    total=False,
)


class CreateAwsLogSourceRequestRequestTypeDef(
    _RequiredCreateAwsLogSourceRequestRequestTypeDef,
    _OptionalCreateAwsLogSourceRequestRequestTypeDef,
):
    pass


ResponseMetadataTypeDef = TypedDict(
    "ResponseMetadataTypeDef",
    {
        "RequestId": str,
        "HostId": str,
        "HTTPStatusCode": int,
        "HTTPHeaders": Dict[str, str],
        "RetryAttempts": int,
    },
)

CreateCustomLogSourceRequestRequestTypeDef = TypedDict(
    "CreateCustomLogSourceRequestRequestTypeDef",
    {
        "customSourceName": str,
        "eventClass": OcsfEventClassType,
        "glueInvocationRoleArn": str,
        "logProviderAccountId": str,
    },
)

CreateDatalakeDelegatedAdminRequestRequestTypeDef = TypedDict(
    "CreateDatalakeDelegatedAdminRequestRequestTypeDef",
    {
        "account": str,
    },
)

CreateDatalakeExceptionsSubscriptionRequestRequestTypeDef = TypedDict(
    "CreateDatalakeExceptionsSubscriptionRequestRequestTypeDef",
    {
        "notificationEndpoint": str,
        "subscriptionProtocol": SubscriptionProtocolTypeType,
    },
)

SourceTypeTypeDef = TypedDict(
    "SourceTypeTypeDef",
    {
        "awsSourceType": AwsLogSourceTypeType,
        "customSourceType": str,
    },
    total=False,
)

_RequiredCreateSubscriptionNotificationConfigurationRequestRequestTypeDef = TypedDict(
    "_RequiredCreateSubscriptionNotificationConfigurationRequestRequestTypeDef",
    {
        "subscriptionId": str,
    },
)
_OptionalCreateSubscriptionNotificationConfigurationRequestRequestTypeDef = TypedDict(
    "_OptionalCreateSubscriptionNotificationConfigurationRequestRequestTypeDef",
    {
        "createSqs": bool,
        "httpsApiKeyName": str,
        "httpsApiKeyValue": str,
        "httpsMethod": HttpsMethodType,
        "roleArn": str,
        "subscriptionEndpoint": str,
    },
    total=False,
)


class CreateSubscriptionNotificationConfigurationRequestRequestTypeDef(
    _RequiredCreateSubscriptionNotificationConfigurationRequestRequestTypeDef,
    _OptionalCreateSubscriptionNotificationConfigurationRequestRequestTypeDef,
):
    pass


_RequiredDeleteAwsLogSourceRequestRequestTypeDef = TypedDict(
    "_RequiredDeleteAwsLogSourceRequestRequestTypeDef",
    {
        "inputOrder": Sequence[DimensionType],
    },
)
_OptionalDeleteAwsLogSourceRequestRequestTypeDef = TypedDict(
    "_OptionalDeleteAwsLogSourceRequestRequestTypeDef",
    {
        "disableAllDimensions": Mapping[str, Mapping[str, Sequence[str]]],
        "disableSingleDimension": Sequence[str],
        "disableTwoDimensions": Mapping[str, Sequence[str]],
    },
    total=False,
)


class DeleteAwsLogSourceRequestRequestTypeDef(
    _RequiredDeleteAwsLogSourceRequestRequestTypeDef,
    _OptionalDeleteAwsLogSourceRequestRequestTypeDef,
):
    pass


DeleteCustomLogSourceRequestRequestTypeDef = TypedDict(
    "DeleteCustomLogSourceRequestRequestTypeDef",
    {
        "customSourceName": str,
    },
)

DeleteDatalakeDelegatedAdminRequestRequestTypeDef = TypedDict(
    "DeleteDatalakeDelegatedAdminRequestRequestTypeDef",
    {
        "account": str,
    },
)

DeleteSubscriberRequestRequestTypeDef = TypedDict(
    "DeleteSubscriberRequestRequestTypeDef",
    {
        "id": str,
    },
)

DeleteSubscriptionNotificationConfigurationRequestRequestTypeDef = TypedDict(
    "DeleteSubscriptionNotificationConfigurationRequestRequestTypeDef",
    {
        "subscriptionId": str,
    },
)

FailuresTypeDef = TypedDict(
    "FailuresTypeDef",
    {
        "exceptionMessage": str,
        "remediation": str,
        "timestamp": datetime,
    },
)

ProtocolAndNotificationEndpointTypeDef = TypedDict(
    "ProtocolAndNotificationEndpointTypeDef",
    {
        "endpoint": str,
        "protocol": str,
    },
    total=False,
)

PaginatorConfigTypeDef = TypedDict(
    "PaginatorConfigTypeDef",
    {
        "MaxItems": int,
        "PageSize": int,
        "StartingToken": str,
    },
    total=False,
)

GetDatalakeStatusRequestRequestTypeDef = TypedDict(
    "GetDatalakeStatusRequestRequestTypeDef",
    {
        "accountSet": Sequence[str],
        "maxAccountResults": int,
        "nextToken": str,
    },
    total=False,
)

GetSubscriberRequestRequestTypeDef = TypedDict(
    "GetSubscriberRequestRequestTypeDef",
    {
        "id": str,
    },
)

RetentionSettingTypeDef = TypedDict(
    "RetentionSettingTypeDef",
    {
        "retentionPeriod": int,
        "storageClass": StorageClassType,
    },
    total=False,
)

ListDatalakeExceptionsRequestRequestTypeDef = TypedDict(
    "ListDatalakeExceptionsRequestRequestTypeDef",
    {
        "maxFailures": int,
        "nextToken": str,
        "regionSet": Sequence[RegionType],
    },
    total=False,
)

ListLogSourcesRequestRequestTypeDef = TypedDict(
    "ListLogSourcesRequestRequestTypeDef",
    {
        "inputOrder": Sequence[DimensionType],
        "listAllDimensions": Mapping[str, Mapping[str, Sequence[str]]],
        "listSingleDimension": Sequence[str],
        "listTwoDimensions": Mapping[str, Sequence[str]],
        "maxResults": int,
        "nextToken": str,
    },
    total=False,
)

ListSubscribersRequestRequestTypeDef = TypedDict(
    "ListSubscribersRequestRequestTypeDef",
    {
        "maxResults": int,
        "nextToken": str,
    },
    total=False,
)

UpdateDatalakeExceptionsExpiryRequestRequestTypeDef = TypedDict(
    "UpdateDatalakeExceptionsExpiryRequestRequestTypeDef",
    {
        "exceptionMessageExpiry": int,
    },
)

UpdateDatalakeExceptionsSubscriptionRequestRequestTypeDef = TypedDict(
    "UpdateDatalakeExceptionsSubscriptionRequestRequestTypeDef",
    {
        "notificationEndpoint": str,
        "subscriptionProtocol": SubscriptionProtocolTypeType,
    },
)

_RequiredUpdateSubscriptionNotificationConfigurationRequestRequestTypeDef = TypedDict(
    "_RequiredUpdateSubscriptionNotificationConfigurationRequestRequestTypeDef",
    {
        "subscriptionId": str,
    },
)
_OptionalUpdateSubscriptionNotificationConfigurationRequestRequestTypeDef = TypedDict(
    "_OptionalUpdateSubscriptionNotificationConfigurationRequestRequestTypeDef",
    {
        "createSqs": bool,
        "httpsApiKeyName": str,
        "httpsApiKeyValue": str,
        "httpsMethod": HttpsMethodType,
        "roleArn": str,
        "subscriptionEndpoint": str,
    },
    total=False,
)


class UpdateSubscriptionNotificationConfigurationRequestRequestTypeDef(
    _RequiredUpdateSubscriptionNotificationConfigurationRequestRequestTypeDef,
    _OptionalUpdateSubscriptionNotificationConfigurationRequestRequestTypeDef,
):
    pass


_RequiredAccountSourcesTypeDef = TypedDict(
    "_RequiredAccountSourcesTypeDef",
    {
        "account": str,
        "sourceType": str,
    },
)
_OptionalAccountSourcesTypeDef = TypedDict(
    "_OptionalAccountSourcesTypeDef",
    {
        "eventClass": OcsfEventClassType,
        "logsStatus": List[LogsStatusTypeDef],
    },
    total=False,
)


class AccountSourcesTypeDef(_RequiredAccountSourcesTypeDef, _OptionalAccountSourcesTypeDef):
    pass


CreateDatalakeAutoEnableRequestRequestTypeDef = TypedDict(
    "CreateDatalakeAutoEnableRequestRequestTypeDef",
    {
        "configurationForNewAccounts": Sequence[AutoEnableNewRegionConfigurationTypeDef],
    },
)

DeleteDatalakeAutoEnableRequestRequestTypeDef = TypedDict(
    "DeleteDatalakeAutoEnableRequestRequestTypeDef",
    {
        "removeFromConfigurationForNewAccounts": Sequence[AutoEnableNewRegionConfigurationTypeDef],
    },
)

CreateAwsLogSourceResponseTypeDef = TypedDict(
    "CreateAwsLogSourceResponseTypeDef",
    {
        "failed": List[str],
        "processing": List[str],
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

CreateCustomLogSourceResponseTypeDef = TypedDict(
    "CreateCustomLogSourceResponseTypeDef",
    {
        "customDataLocation": str,
        "glueCrawlerName": str,
        "glueDatabaseName": str,
        "glueTableName": str,
        "logProviderAccessRoleArn": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

CreateSubscriberResponseTypeDef = TypedDict(
    "CreateSubscriberResponseTypeDef",
    {
        "roleArn": str,
        "s3BucketArn": str,
        "snsArn": str,
        "subscriptionId": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

CreateSubscriptionNotificationConfigurationResponseTypeDef = TypedDict(
    "CreateSubscriptionNotificationConfigurationResponseTypeDef",
    {
        "queueArn": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

DeleteAwsLogSourceResponseTypeDef = TypedDict(
    "DeleteAwsLogSourceResponseTypeDef",
    {
        "failed": List[str],
        "processing": List[str],
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

DeleteCustomLogSourceResponseTypeDef = TypedDict(
    "DeleteCustomLogSourceResponseTypeDef",
    {
        "customDataLocation": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

DeleteDatalakeExceptionsSubscriptionResponseTypeDef = TypedDict(
    "DeleteDatalakeExceptionsSubscriptionResponseTypeDef",
    {
        "status": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

GetDatalakeAutoEnableResponseTypeDef = TypedDict(
    "GetDatalakeAutoEnableResponseTypeDef",
    {
        "autoEnableNewAccounts": List[AutoEnableNewRegionConfigurationTypeDef],
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

GetDatalakeExceptionsExpiryResponseTypeDef = TypedDict(
    "GetDatalakeExceptionsExpiryResponseTypeDef",
    {
        "exceptionMessageExpiry": int,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

ListLogSourcesResponseTypeDef = TypedDict(
    "ListLogSourcesResponseTypeDef",
    {
        "nextToken": str,
        "regionSourceTypesAccountsList": List[Dict[str, Dict[str, List[str]]]],
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

UpdateSubscriptionNotificationConfigurationResponseTypeDef = TypedDict(
    "UpdateSubscriptionNotificationConfigurationResponseTypeDef",
    {
        "queueArn": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

_RequiredCreateSubscriberRequestRequestTypeDef = TypedDict(
    "_RequiredCreateSubscriberRequestRequestTypeDef",
    {
        "accountId": str,
        "externalId": str,
        "sourceTypes": Sequence[SourceTypeTypeDef],
        "subscriberName": str,
    },
)
_OptionalCreateSubscriberRequestRequestTypeDef = TypedDict(
    "_OptionalCreateSubscriberRequestRequestTypeDef",
    {
        "accessTypes": Sequence[AccessTypeType],
        "subscriberDescription": str,
    },
    total=False,
)


class CreateSubscriberRequestRequestTypeDef(
    _RequiredCreateSubscriberRequestRequestTypeDef, _OptionalCreateSubscriberRequestRequestTypeDef
):
    pass


_RequiredSubscriberResourceTypeDef = TypedDict(
    "_RequiredSubscriberResourceTypeDef",
    {
        "accountId": str,
        "sourceTypes": List[SourceTypeTypeDef],
        "subscriptionId": str,
    },
)
_OptionalSubscriberResourceTypeDef = TypedDict(
    "_OptionalSubscriberResourceTypeDef",
    {
        "accessTypes": List[AccessTypeType],
        "createdAt": datetime,
        "externalId": str,
        "roleArn": str,
        "s3BucketArn": str,
        "snsArn": str,
        "subscriberDescription": str,
        "subscriberName": str,
        "subscriptionEndpoint": str,
        "subscriptionProtocol": EndpointProtocolType,
        "subscriptionStatus": SubscriptionStatusType,
        "updatedAt": datetime,
    },
    total=False,
)


class SubscriberResourceTypeDef(
    _RequiredSubscriberResourceTypeDef, _OptionalSubscriberResourceTypeDef
):
    pass


_RequiredUpdateSubscriberRequestRequestTypeDef = TypedDict(
    "_RequiredUpdateSubscriberRequestRequestTypeDef",
    {
        "id": str,
        "sourceTypes": Sequence[SourceTypeTypeDef],
    },
)
_OptionalUpdateSubscriberRequestRequestTypeDef = TypedDict(
    "_OptionalUpdateSubscriberRequestRequestTypeDef",
    {
        "externalId": str,
        "subscriberDescription": str,
        "subscriberName": str,
    },
    total=False,
)


class UpdateSubscriberRequestRequestTypeDef(
    _RequiredUpdateSubscriberRequestRequestTypeDef, _OptionalUpdateSubscriberRequestRequestTypeDef
):
    pass


FailuresResponseTypeDef = TypedDict(
    "FailuresResponseTypeDef",
    {
        "failures": List[FailuresTypeDef],
        "region": str,
    },
    total=False,
)

GetDatalakeExceptionsSubscriptionResponseTypeDef = TypedDict(
    "GetDatalakeExceptionsSubscriptionResponseTypeDef",
    {
        "protocolAndNotificationEndpoint": ProtocolAndNotificationEndpointTypeDef,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

GetDatalakeStatusRequestGetDatalakeStatusPaginateTypeDef = TypedDict(
    "GetDatalakeStatusRequestGetDatalakeStatusPaginateTypeDef",
    {
        "accountSet": Sequence[str],
        "PaginationConfig": PaginatorConfigTypeDef,
    },
    total=False,
)

ListDatalakeExceptionsRequestListDatalakeExceptionsPaginateTypeDef = TypedDict(
    "ListDatalakeExceptionsRequestListDatalakeExceptionsPaginateTypeDef",
    {
        "regionSet": Sequence[RegionType],
        "PaginationConfig": PaginatorConfigTypeDef,
    },
    total=False,
)

ListLogSourcesRequestListLogSourcesPaginateTypeDef = TypedDict(
    "ListLogSourcesRequestListLogSourcesPaginateTypeDef",
    {
        "inputOrder": Sequence[DimensionType],
        "listAllDimensions": Mapping[str, Mapping[str, Sequence[str]]],
        "listSingleDimension": Sequence[str],
        "listTwoDimensions": Mapping[str, Sequence[str]],
        "PaginationConfig": PaginatorConfigTypeDef,
    },
    total=False,
)

ListSubscribersRequestListSubscribersPaginateTypeDef = TypedDict(
    "ListSubscribersRequestListSubscribersPaginateTypeDef",
    {
        "PaginationConfig": PaginatorConfigTypeDef,
    },
    total=False,
)

LakeConfigurationRequestTypeDef = TypedDict(
    "LakeConfigurationRequestTypeDef",
    {
        "encryptionKey": str,
        "replicationDestinationRegions": Sequence[RegionType],
        "replicationRoleArn": str,
        "retentionSettings": Sequence[RetentionSettingTypeDef],
        "tagsMap": Mapping[str, str],
    },
    total=False,
)

LakeConfigurationResponseTypeDef = TypedDict(
    "LakeConfigurationResponseTypeDef",
    {
        "encryptionKey": str,
        "replicationDestinationRegions": List[RegionType],
        "replicationRoleArn": str,
        "retentionSettings": List[RetentionSettingTypeDef],
        "s3BucketArn": str,
        "status": settingsStatusType,
        "tagsMap": Dict[str, str],
    },
    total=False,
)

GetDatalakeStatusResponseTypeDef = TypedDict(
    "GetDatalakeStatusResponseTypeDef",
    {
        "accountSourcesList": List[AccountSourcesTypeDef],
        "nextToken": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

GetSubscriberResponseTypeDef = TypedDict(
    "GetSubscriberResponseTypeDef",
    {
        "subscriber": SubscriberResourceTypeDef,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

ListSubscribersResponseTypeDef = TypedDict(
    "ListSubscribersResponseTypeDef",
    {
        "nextToken": str,
        "subscribers": List[SubscriberResourceTypeDef],
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

UpdateSubscriberResponseTypeDef = TypedDict(
    "UpdateSubscriberResponseTypeDef",
    {
        "subscriber": SubscriberResourceTypeDef,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

ListDatalakeExceptionsResponseTypeDef = TypedDict(
    "ListDatalakeExceptionsResponseTypeDef",
    {
        "nextToken": str,
        "nonRetryableFailures": List[FailuresResponseTypeDef],
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

CreateDatalakeRequestRequestTypeDef = TypedDict(
    "CreateDatalakeRequestRequestTypeDef",
    {
        "configurations": Mapping[RegionType, LakeConfigurationRequestTypeDef],
        "enableAll": bool,
        "metaStoreManagerRoleArn": str,
        "regions": Sequence[RegionType],
    },
    total=False,
)

UpdateDatalakeRequestRequestTypeDef = TypedDict(
    "UpdateDatalakeRequestRequestTypeDef",
    {
        "configurations": Mapping[RegionType, LakeConfigurationRequestTypeDef],
    },
)

GetDatalakeResponseTypeDef = TypedDict(
    "GetDatalakeResponseTypeDef",
    {
        "configurations": Dict[RegionType, LakeConfigurationResponseTypeDef],
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)



"""
Type annotations for securitylake service client paginators.

[Open documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/paginators/)

Usage::

    ```python
    from aiobotocore.session import get_session

    from types_aiobotocore_securitylake.client import SecurityLakeClient
    from types_aiobotocore_securitylake.paginator import (
        GetDatalakeStatusPaginator,
        ListDatalakeExceptionsPaginator,
        ListLogSourcesPaginator,
        ListSubscribersPaginator,
    )

    session = get_session()
    with session.create_client("securitylake") as client:
        client: SecurityLakeClient

        get_datalake_status_paginator: GetDatalakeStatusPaginator = client.get_paginator("get_datalake_status")
        list_datalake_exceptions_paginator: ListDatalakeExceptionsPaginator = client.get_paginator("list_datalake_exceptions")
        list_log_sources_paginator: ListLogSourcesPaginator = client.get_paginator("list_log_sources")
        list_subscribers_paginator: ListSubscribersPaginator = client.get_paginator("list_subscribers")
    ```
"""
import sys
from typing import Generic, Iterator, Mapping, Sequence, TypeVar

from aiobotocore.paginate import AioPaginator
from botocore.paginate import PageIterator

from .literals import DimensionType, RegionType
from .type_defs import (
    GetDatalakeStatusResponseTypeDef,
    ListDatalakeExceptionsResponseTypeDef,
    ListLogSourcesResponseTypeDef,
    ListSubscribersResponseTypeDef,
    PaginatorConfigTypeDef,
)

if sys.version_info >= (3, 8):
    from typing import AsyncIterator
else:
    from typing_extensions import AsyncIterator

__all__ = (
    "GetDatalakeStatusPaginator",
    "ListDatalakeExceptionsPaginator",
    "ListLogSourcesPaginator",
    "ListSubscribersPaginator",
)

_ItemTypeDef = TypeVar("_ItemTypeDef")

class _PageIterator(Generic[_ItemTypeDef], PageIterator):
    def __iter__(self) -> Iterator[_ItemTypeDef]:
        """
        Proxy method to specify iterator item type.
        """

class GetDatalakeStatusPaginator(AioPaginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Paginator.GetDatalakeStatus)
    [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/paginators/#getdatalakestatuspaginator)
    """

    def paginate(
        self, *, accountSet: Sequence[str] = ..., PaginationConfig: PaginatorConfigTypeDef = ...
    ) -> AsyncIterator[GetDatalakeStatusResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Paginator.GetDatalakeStatus.paginate)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/paginators/#getdatalakestatuspaginator)
        """

class ListDatalakeExceptionsPaginator(AioPaginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Paginator.ListDatalakeExceptions)
    [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/paginators/#listdatalakeexceptionspaginator)
    """

    def paginate(
        self,
        *,
        regionSet: Sequence[RegionType] = ...,
        PaginationConfig: PaginatorConfigTypeDef = ...
    ) -> AsyncIterator[ListDatalakeExceptionsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Paginator.ListDatalakeExceptions.paginate)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/paginators/#listdatalakeexceptionspaginator)
        """

class ListLogSourcesPaginator(AioPaginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Paginator.ListLogSources)
    [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/paginators/#listlogsourcespaginator)
    """

    def paginate(
        self,
        *,
        inputOrder: Sequence[DimensionType] = ...,
        listAllDimensions: Mapping[str, Mapping[str, Sequence[str]]] = ...,
        listSingleDimension: Sequence[str] = ...,
        listTwoDimensions: Mapping[str, Sequence[str]] = ...,
        PaginationConfig: PaginatorConfigTypeDef = ...
    ) -> AsyncIterator[ListLogSourcesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Paginator.ListLogSources.paginate)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/paginators/#listlogsourcespaginator)
        """

class ListSubscribersPaginator(AioPaginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Paginator.ListSubscribers)
    [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/paginators/#listsubscriberspaginator)
    """

    def paginate(
        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
    ) -> AsyncIterator[ListSubscribersResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#SecurityLake.Paginator.ListSubscribers.paginate)
        [Show types-aiobotocore documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/paginators/#listsubscriberspaginator)
        """
